django_analyses.serializers.pipeline package — django_analyses 0.0.3 documentation

# django_analyses.serializers.pipeline package

## Submodules

## django_analyses.serializers.pipeline.node module

class `django_analyses.serializers.pipeline.node.` `NodeSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'analysis_version', 'configuration', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.pipeline.node.Node`

## django_analyses.serializers.pipeline.pipe module

class `django_analyses.serializers.pipeline.pipe.` `PipeSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'pipeline', 'source', 'source_port', 'destination', 'destination_port', 'url')
    `model`

      alias of `django_analyses.models.pipeline.pipe.Pipe`

## django_analyses.serializers.pipeline.pipeline module

class `django_analyses.serializers.pipeline.pipeline.` `PipelineSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'title', 'description', 'node_set', 'pipe_set', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.pipeline.pipeline.Pipeline`

## Module contents